Package: OptimalCutpoints
Type: Package
Title: Computing Optimal Cutpoints in Diagnostic Tests
Version: 1.1-5
Date: 2021-10-06
Author: Monica Lopez-Raton, Maria Xose Rodriguez-Alvarez
Maintainer: Monica Lopez Raton <monica.lopez.raton@gmail.com>
Description: Computes optimal cutpoints for diagnostic tests or continuous markers. Various approaches for selecting optimal cutoffs have been implemented, including methods based on cost-benefit analysis and diagnostic test accuracy measures (Sensitivity/Specificity, Predictive Values and Diagnostic Likelihood Ratios). Numerical and graphical output for all methods is easily obtained.
Imports: stats, graphics
License: GPL
LazyLoad: yes
NeedsCompilation: no
Packaged: 2021-10-06 19:09:27 UTC; mrodriguez
Repository: CRAN
Date/Publication: 2021-10-07 10:30:05 UTC
Built: R 4.6.0; ; 2026-04-25 18:25:57 UTC; unix
